Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(909)

Unified Diff: net/socket/ssl_client_socket.h

Issue 2337253004: Update Token Binding code to the latest drafts (Closed)
Patch Set: Fix compilation error in unit_tests Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/socket/ssl_client_socket.h
diff --git a/net/socket/ssl_client_socket.h b/net/socket/ssl_client_socket.h
index 4bf6a0846a26025e8af7c94963b8e5f2dd59910c..a081ae83d11dd4020096c83460471b52483b92fe 100644
--- a/net/socket/ssl_client_socket.h
+++ b/net/socket/ssl_client_socket.h
@@ -16,6 +16,7 @@
#include "net/base/net_errors.h"
#include "net/socket/ssl_socket.h"
#include "net/socket/stream_socket.h"
+#include "net/ssl/token_binding.h"
namespace base {
class FilePath;
@@ -129,10 +130,12 @@ class NET_EXPORT SSLClientSocket : public SSLSocket {
// channel ids are not supported.
virtual ChannelIDService* GetChannelIDService() const = 0;
- // Signs the EKM value for Token Binding with |*key| and puts it in |*out|.
- // Returns a net error code.
- virtual Error GetSignedEKMForTokenBinding(crypto::ECPrivateKey* key,
- std::vector<uint8_t>* out) = 0;
+ // Generates the signature used in Token Binding using key |*key| and for a
+ // Token Binding of type |tb_type|, putting the signature in |*out|. Returns a
+ // net error code.
+ virtual Error GetTokenBindingSignature(crypto::ECPrivateKey* key,
+ TokenBindingType tb_type,
+ std::vector<uint8_t>* out) = 0;
// This method is only for debugging crbug.com/548423 and will be removed when
// that bug is closed. This returns the channel ID key that was used when

Powered by Google App Engine
This is Rietveld 408576698